CHANGELOG
=========

0.1.3          (2020-11-16)
---------------------------

* Tiles is not required anymore for add / edit mapbox base layer


0.1.2          (2020-11-03)
---------------------------

* API enhancement
  * Manage raster tiles urls
  * Add TileJSON url in MapBoxBaseLayerSerializer


0.1.1          (2020-10-12)
---------------------------

* Fix typo preventing BaseLayerSerializer from working properly


0.1.0          (2020-10-06)
---------------------------

* First release of django-terra-settings
